==> qgis_3.10.4+dfsg.orig.tar.xz: qgis-3.10.4/src/server/services/wms/qgswmsgetfeatureinfo.h <==
/***************************************************************************
                              qgswmsgetfeatureinfo.h
                              -------------------------
  begin                : December 20 , 2016
  copyright            : (C) 2007 by Marco Hugentobler  (original code)
                         (C) 2014 by Alessandro Pasotti (original code)
                         (C) 2016 by David Marteau
  email                : marco dot hugentobler at karto dot baug dot ethz dot ch
                         a dot pasotti at itopen dot it
                         david dot marteau at 3liz dot com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

namespace QgsWms
{

  /**
   * Output GetFeatureInfo response
   */
  void writeGetFeatureInfo( QgsServerInterface *serverIface, const QgsProject *project,
                            const QString &version, const QgsServerRequest &request,
                            QgsServerResponse &response );

} // namespace QgsWms

==> qgis_3.34.10+dfsg.orig.tar.xz: qgis-3.34.10/src/server/services/wms/qgswmsgetfeatureinfo.h <==
/***************************************************************************
                              qgswmsgetfeatureinfo.h
                              -------------------------
  begin                : December 20 , 2016
  copyright            : (C) 2007 by Marco Hugentobler  (original code)
                         (C) 2014 by Alessandro Pasotti (original code)
                         (C) 2016 by David Marteau
  email                : marco dot hugentobler at karto dot baug dot ethz dot ch
                         a dot pasotti at itopen dot it
                         david dot marteau at 3liz dot com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "qgswmsrequest.h"

namespace QgsWms
{

  /**
   * Output GetFeatureInfo response
   */
  void writeGetFeatureInfo( QgsServerInterface *serverIface, const QgsProject *project,
                            const QgsWmsRequest &request,
                            QgsServerResponse &response );

} // namespace QgsWms
